--***************************************************************
--* File         : WBVER.vhd                                    *
--* Created      : time-stamp: <08/07/30 06:37:49 kawasan>      *
--* Modified     : Time-stamp: <08/08/26 02:23:52 kawasan>      *
--*                                                             *
--* For management of design version                            *
--*                                                             *
--* Copyright 2008 Osamu Kawashima. all rights reserved         *
--***************************************************************

library ieee;
use ieee.std_logic_1164.all;

entity WBVER is
	generic (
		-- Version-Code = ver AB01 (rel 01)
		VERSION_CODE0   : std_logic_vector := x"41";	-- A:Device_Name-High
		VERSION_CODE1   : std_logic_vector := x"42";	-- B:Device_Name-Low
		VERSION_CODE2   : std_logic_vector := x"30";	-- 0:Version-High
		VERSION_CODE3   : std_logic_vector := x"31";	-- 1:Version-Low
		RELEASE_CODE0	: std_logic_vector := x"30";	-- 0:Release-High
		RELEASE_CODE1	: std_logic_vector := x"31"	-- 1:Release-Low
	);
	port (
		-- WISHBONE SLAVE interface:
		WB_CLK_I        : in    std_logic;
		WB_RST_I        : in    std_logic;
		WB_ADR_I        : in    std_logic_vector(7 downto 0);
		WB_DAT_I        : in    std_logic_vector(7 downto 0);
		WB_WE_I         : in    std_logic;
		WB_STB_I        : in    std_logic;
		WB_ACK_O        : out   std_logic;
		WB_DAT_O        : out   std_logic_vector(7 downto 0)
	);
end WBVER;

architecture RTL of WBVER is

	constant ZERO32         : std_logic_vector(31 downto 0) := (others=>'0');

	-- Address
	constant C_VER_LL       : std_logic_vector := x"0";
	constant C_VER_LH       : std_logic_vector := x"1";
	constant C_VER_HL       : std_logic_vector := x"2";
	constant C_VER_HH       : std_logic_vector := x"3";
	constant C_REL_L        : std_logic_vector := x"4";
	constant C_REL_H        : std_logic_vector := x"5";

	signal add_h            : std_logic_vector(7 downto 4);
	signal add_l            : std_logic_vector(3 downto 0);
	signal active_add       : std_logic := '0';

begin

	add_h <= WB_ADR_I(7 downto 4);
	add_l <= WB_ADR_I(3 downto 0);
	active_add <= '1' when add_h=x"0" and WB_STB_I='1' else '0';

	WB_DAT_O <= VERSION_CODE0 when active_add='1' and add_l=C_VER_LL else
	            VERSION_CODE1 when active_add='1' and add_l=C_VER_LH else
	            VERSION_CODE2 when active_add='1' and add_l=C_VER_HL else
	            VERSION_CODE3 when active_add='1' and add_l=C_VER_HH else
	            RELEASE_CODE0 when active_add='1' and add_l=C_REL_L  else
	            RELEASE_CODE1 when active_add='1' and add_l=C_REL_H  else
		    (others=>'0');

	WB_ACK_O <= WB_STB_I;

end RTL;
